#region Using declarations
using System;
using System.ComponentModel;
using System.Diagnostics;
using System.Drawing;
using System.Drawing.Drawing2D;
using System.Xml.Serialization;
using NinjaTrader.Cbi;
using NinjaTrader.Data;
using NinjaTrader.Gui.Chart;
#endregion

// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    /// <summary>
    /// A moving average which adapts to new jumps in volatility
    /// </summary>
    [Description("A moving average which adapts to new jumps in volatility")]
    public class VolatilityMA : Indicator
    {
        #region Variables
        // Wizard generated variables
        // User defined variables (add any user defined variables below)
        #endregion
		
		private int period = 1;
		
        /// <summary>
        /// This method is used to configure the indicator and is called once before any bar data is loaded.
        /// </summary>
        protected override void Initialize()
        {
            Add(new Plot(Color.FromKnownColor(KnownColor.Black), PlotStyle.Line, "MA"));
            Overlay				= true;
			BarsRequired		= 300;
        }

        /// <summary>
        /// Called on each bar update event (incoming tick)
        /// </summary>
        protected override void OnBarUpdate()
        {
			if( CurrentBar < BarsRequired )
				return;
			
			double val = Vols()[0];					
			
			if( Math.Abs( Vols()[0] ) > 2 )
				period = 1;
			else
				period++;
			
            MA.Set(SMA(period)[0]);
        }

        #region Properties
        [Browsable(false)]	// this line prevents the data series from being displayed in the indicator properties dialog, do not remove
        [XmlIgnore()]		// this line ensures that the indicator can be saved/recovered as part of a chart template, do not remove
        public DataSeries MA
        {
            get { return Values[0]; }
        }

        #endregion
    }
}

#region NinjaScript generated code. Neither change nor remove.
// This namespace holds all indicators and is required. Do not change it.
namespace NinjaTrader.Indicator
{
    public partial class Indicator : IndicatorBase
    {
        private VolatilityMA[] cacheVolatilityMA = null;

        private static VolatilityMA checkVolatilityMA = new VolatilityMA();

        /// <summary>
        /// A moving average which adapts to new jumps in volatility
        /// </summary>
        /// <returns></returns>
        public VolatilityMA VolatilityMA()
        {
            return VolatilityMA(Input);
        }

        /// <summary>
        /// A moving average which adapts to new jumps in volatility
        /// </summary>
        /// <returns></returns>
        public VolatilityMA VolatilityMA(Data.IDataSeries input)
        {
            if (cacheVolatilityMA != null)
                for (int idx = 0; idx < cacheVolatilityMA.Length; idx++)
                    if (cacheVolatilityMA[idx].EqualsInput(input))
                        return cacheVolatilityMA[idx];

            lock (checkVolatilityMA)
            {
                if (cacheVolatilityMA != null)
                    for (int idx = 0; idx < cacheVolatilityMA.Length; idx++)
                        if (cacheVolatilityMA[idx].EqualsInput(input))
                            return cacheVolatilityMA[idx];

                VolatilityMA indicator = new VolatilityMA();
                indicator.BarsRequired = BarsRequired;
                indicator.CalculateOnBarClose = CalculateOnBarClose;
#if NT7
                indicator.ForceMaximumBarsLookBack256 = ForceMaximumBarsLookBack256;
                indicator.MaximumBarsLookBack = MaximumBarsLookBack;
#endif
                indicator.Input = input;
                Indicators.Add(indicator);
                indicator.SetUp();

                VolatilityMA[] tmp = new VolatilityMA[cacheVolatilityMA == null ? 1 : cacheVolatilityMA.Length + 1];
                if (cacheVolatilityMA != null)
                    cacheVolatilityMA.CopyTo(tmp, 0);
                tmp[tmp.Length - 1] = indicator;
                cacheVolatilityMA = tmp;
                return indicator;
            }
        }
    }
}

// This namespace holds all market analyzer column definitions and is required. Do not change it.
namespace NinjaTrader.MarketAnalyzer
{
    public partial class Column : ColumnBase
    {
        /// <summary>
        /// A moving average which adapts to new jumps in volatility
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.VolatilityMA VolatilityMA()
        {
            return _indicator.VolatilityMA(Input);
        }

        /// <summary>
        /// A moving average which adapts to new jumps in volatility
        /// </summary>
        /// <returns></returns>
        public Indicator.VolatilityMA VolatilityMA(Data.IDataSeries input)
        {
            return _indicator.VolatilityMA(input);
        }
    }
}

// This namespace holds all strategies and is required. Do not change it.
namespace NinjaTrader.Strategy
{
    public partial class Strategy : StrategyBase
    {
        /// <summary>
        /// A moving average which adapts to new jumps in volatility
        /// </summary>
        /// <returns></returns>
        [Gui.Design.WizardCondition("Indicator")]
        public Indicator.VolatilityMA VolatilityMA()
        {
            return _indicator.VolatilityMA(Input);
        }

        /// <summary>
        /// A moving average which adapts to new jumps in volatility
        /// </summary>
        /// <returns></returns>
        public Indicator.VolatilityMA VolatilityMA(Data.IDataSeries input)
        {
            if (InInitialize && input == null)
                throw new ArgumentException("You only can access an indicator with the default input/bar series from within the 'Initialize()' method");

            return _indicator.VolatilityMA(input);
        }
    }
}
#endregion
